pub struct Options {
pub dir_action: DirAction,
pub filter: FileFilter,
pub view: View,
pub theme: Options,
pub stdin: FilesInput,
}Expand description
These options represent a parsed, error-checked versions of the user’s command-line options.
Fields
dir_action: DirActionThe action to perform when encountering a directory rather than a regular file.
filter: FileFilterHow to sort and filter files before outputting them.
view: ViewThe user’s preference of view to use (lines, grid, details, or grid-details) along with the options on how to render file names. If the view requires the terminal to have a width, and there is no width, then the view will be downgraded.
theme: OptionsThe options to make up the styles of the UI and file names.
stdin: FilesInputWhether to read file names from stdin instead of the command-line
Implementations
sourceimpl Options
impl Options
sourcepub fn parse<'args, I, V>(args: I, vars: &V) -> OptionsResult<'args>
pub fn parse<'args, I, V>(args: I, vars: &V) -> OptionsResult<'args>
Parse the given iterator of command-line strings into an Options struct and a list of free filenames, using the environment variables for extra options.
sourcepub fn should_scan_for_git(&self) -> bool
pub fn should_scan_for_git(&self) -> bool
Whether the View specified in this set of options includes a Git status column. It’s only worth trying to discover a repository if the results will end up being displayed.