pub enum Classify {
JustFilenames,
AddFileIndicators,
AutomaticAddFileIndicators,
}Expand description
Whether to append file class characters to the file names.
Variants
JustFilenames
Just display the file names, without any characters.
AddFileIndicators
Always add a character after the file name depending on what class of file it is.
AutomaticAddFileIndicators