Enum eza::output::time::TimeFormat
source · pub enum TimeFormat {
DefaultFormat,
ISOFormat,
LongISO,
FullISO,
Relative,
Custom {
non_recent: String,
recent: Option<String>,
},
}Expand description
Every timestamp in exa needs to be rendered by a time format. Formatting times is tricky, because how a timestamp is rendered can depend on one or more of the following:
- The user’s locale, for printing the month name as “Feb”, or as “fév”, or as “2月”;
- The current year, because certain formats will be less precise when dealing with dates far in the past;
- The formatting style that the user asked for on the command-line.
Because not all formatting styles need the same data, they all have their own enum variants. It’s not worth looking the locale up if the formatter prints month names as numbers.
Also, eza supports custom styles, where the user enters a format string in an environment variable or something. Just these four.
Variants
DefaultFormat
The default format uses the user’s locale to print month names, and specifies the timestamp down to the minute for recent times, and day for older times.
ISOFormat
Use the ISO format, which specifies the timestamp down to the minute for recent times, and day for older times. It uses a number for the month so it doesn’t use the locale.
LongISO
Use the long ISO format, which specifies the timestamp down to the minute using only numbers, without needing the locale or year.
FullISO
Use the full ISO format, which specifies the timestamp down to the millisecond and includes its offset down to the minute. This too uses only numbers so doesn’t require any special consideration.
Relative
Use a relative but fixed width representation.
Custom
Use custom formats, optionally a different custom format can be specified for recent times, otherwise the same custom format will be used for both recent and non-recent times.
Implementations
sourceimpl TimeFormat
impl TimeFormat
pub fn format(self, time: &DateTime<FixedOffset>) -> String