eza
0.22.1
Module theme
Module Items
Structs
Enums
Traits
In crate eza
eza
Module
theme
Structs

Definitions
LSColors
Options
Theme
UiStyles
Enums

UseColours
Under what circumstances we should display coloured, rather than plain, output to the terminal.
Traits

File
Style
Determine the style to paint the text for the filename part of the output.