pub enum UseColours {
Always,
Automatic,
Never,
}Expand description
Under what circumstances we should display coloured, rather than plain, output to the terminal.
By default, we want to display the colours when stdout can display them.
Turning them on when output is going to, say, a pipe, would make programs
such as grep or more not work properly. So the Automatic mode does
this check and only displays colours when they can be truly appreciated.
Variants
Always
Display them even when output isn’t going to a terminal.
Automatic
Display them when output is going to a terminal, but not otherwise.
Never
Never display them, even when output is going to a terminal.