Modules
- color_
scale - details
- The Details output view displays each file as a row in a table.
- file_
name - grid
- grid_
details - The grid-details view lists several details views side-by-side.
- icons
- lines
- render
- table
- time
- Timestamp formatting.
Structs
- View
- The view contains all information about how to format output.
Enums
- Mode
- The mode is the “type” of output.
- Terminal
Width - The width of the terminal requested by the user.