Module eza::output

source ·

Modules

Structs

  • The Unicode “display width” of a string.
  • An individual cell that holds text in a table, used in the details and lines views to store ANSI-terminal-formatted data before it is printed.
  • The contents of a text cell, as a vector of ANSI-styled strings.
  • The view contains all information about how to format output.

Enums

  • The mode is the “type” of output.
  • The width of the terminal requested by the user.

Functions